cleanup
diff --git a/org.eclipse.jface.text/src/org/eclipse/jface/text/TextViewerHoverManager.java b/org.eclipse.jface.text/src/org/eclipse/jface/text/TextViewerHoverManager.java
index edcda05..98ae893 100644
--- a/org.eclipse.jface.text/src/org/eclipse/jface/text/TextViewerHoverManager.java
+++ b/org.eclipse.jface.text/src/org/eclipse/jface/text/TextViewerHoverManager.java
@@ -43,10 +43,10 @@
 	/** The currently shown text hover. */
 	private volatile ITextHover fTextHover;
 	/**
 	 * The current information control creator.
 	 * @since 3.0
 	 */
-	private volatile IInformationControlCreator fCurrentInformationControlCreator;	
+	private volatile IInformationControlCreator fCustomInformationControlCreator;	
 	/**
 	 * Tells whether a custom information control is in use.
 	 * @since 3.0
@@ -129,9 +129,9 @@
 							information= null;
 						}
 						
-						fCurrentInformationControlCreator= null;
+						fCustomInformationControlCreator= null;
 						if (hover instanceof ITextHoverExtension)
-							fCurrentInformationControlCreator= ((ITextHoverExtension)hover).getInformationControlCreator();	
+							fCustomInformationControlCreator= ((ITextHoverExtension) hover).getInformationControlCreator();	
 						setInformation(information, area);
 						if (information != null && area != null)
 							fTextHover= hover;
@@ -334,12 +334,12 @@
 	}
 
 	/*
-	 * @see #getInformationControl()
+	 * @see org.eclipse.jface.text.AbstractInformationControlManager#getInformationControl()
 	 * @since 3.0
 	 */
 	protected IInformationControl getInformationControl() {
 		
-		if (fCurrentInformationControlCreator == null || fDisposed) {
+		if (fCustomInformationControlCreator == null || fDisposed) {
 			if (fIsCustomInformtionControl) {
 				fInformationControl.dispose();
 				fInformationControl= null;
@@ -348,14 +348,14 @@
 			return super.getInformationControl();
 		}
 
-		if ((fCurrentInformationControlCreator instanceof IInformationControlCreatorExtension)
-				&& ((IInformationControlCreatorExtension)fCurrentInformationControlCreator).canBeReused(fInformationControl))
+		if ((fCustomInformationControlCreator instanceof IInformationControlCreatorExtension)
+				&& ((IInformationControlCreatorExtension) fCustomInformationControlCreator).canBeReused(fInformationControl))
 			return fInformationControl;
 
 		if (fInformationControl != null)
 			fInformationControl.dispose();
 			
-		fInformationControl= fCurrentInformationControlCreator.createInformationControl(getSubjectControl().getShell());
+		fInformationControl= fCustomInformationControlCreator.createInformationControl(getSubjectControl().getShell());
 		fIsCustomInformtionControl= true;
 		fInformationControl.addDisposeListener(new DisposeListener() {
 			public void widgetDisposed(DisposeEvent e) {
@@ -43,10 +43,10 @@
 	private volatile ITextHover fTextHover;
 	/**
-	 * The current information control creator.
+	 * The custom information control creator.
 	 * @since 3.0
 	 */
diff --git a/org.eclipse.jface.text/src/org/eclipse/jface/text/information/InformationPresenter.java b/org.eclipse.jface.text/src/org/eclipse/jface/text/information/InformationPresenter.java
index d34b746..d255969 100644
--- a/org.eclipse.jface.text/src/org/eclipse/jface/text/information/InformationPresenter.java
+++ b/org.eclipse.jface.text/src/org/eclipse/jface/text/information/InformationPresenter.java
@@ -63,8 +63,7 @@
 	 * Internal information control closer. Listens to several events issued by its subject control
 	 * and closes the information control when necessary.
 	 */
-	class Closer implements IInformationControlCloser, ControlListener, MouseListener, 
-							FocusListener, IViewportListener, KeyListener {
+	class Closer implements IInformationControlCloser, ControlListener, MouseListener, FocusListener, IViewportListener, KeyListener {
 		
 		/** The subject control */
 		private Control fSubjectControl;
@@ -215,10 +214,10 @@
 	/** The offset to override selection. */
 	private int fOffset= -1;
 	/**
 	 * The current information control creator.
 	 * @since 3.0
 	 */
-	private IInformationControlCreator fCurrentInformationControlCreator;	
+	private IInformationControlCreator fCustomInformationControlCreator;	
 	/**
 	 * Tells whether a custom information control is in use.
 	 * @since 3.0
@@ -308,9 +307,9 @@
 		if (subject == null)
 			return;
 
-		fCurrentInformationControlCreator= null;
+		fCustomInformationControlCreator= null;
 		if (provider instanceof IInformationProviderExtension2)
-			fCurrentInformationControlCreator= ((IInformationProviderExtension2)provider).getInformationPresenterControlCreator();	
+			fCustomInformationControlCreator= ((IInformationProviderExtension2) provider).getInformationPresenterControlCreator();	
 
 		if (provider instanceof IInformationProviderExtension) {
 			IInformationProviderExtension extension= (IInformationProviderExtension) provider;
@@ -447,12 +446,12 @@
 	}
 	
 	/*
-	 * @see #getInformationControl()
+	 * @see org.eclipse.jface.text.AbstractInformationControlManager#getInformationControl()
 	 * @since 3.0
 	 */
 	protected IInformationControl getInformationControl() {
 		
-		if (fCurrentInformationControlCreator == null || fDisposed) {
+		if (fCustomInformationControlCreator == null || fDisposed) {
 			if (fIsCustomInformtionControl) {
 				fInformationControl.dispose();
 				fInformationControl= null;
@@ -461,14 +460,14 @@
 			return super.getInformationControl();
 		}
 
-		if ((fCurrentInformationControlCreator instanceof IInformationControlCreatorExtension)
-				&& ((IInformationControlCreatorExtension)fCurrentInformationControlCreator).canBeReused(fInformationControl))
+		if ((fCustomInformationControlCreator instanceof IInformationControlCreatorExtension)
+				&& ((IInformationControlCreatorExtension) fCustomInformationControlCreator).canBeReused(fInformationControl))
 			return fInformationControl;
 
 		if (fInformationControl != null)
 			fInformationControl.dispose();
 			
-		fInformationControl= fCurrentInformationControlCreator.createInformationControl(getSubjectControl().getShell());
+		fInformationControl= fCustomInformationControlCreator.createInformationControl(getSubjectControl().getShell());
 		fIsCustomInformtionControl= true;
 		fInformationControl.addDisposeListener(new DisposeListener() {
 			public void widgetDisposed(DisposeEvent e) {
@@ -215,10 +214,10 @@
 	private int fOffset= -1;
 	/**
-	 * The current information control creator.
+	 * The custom information control creator.
 	 * @since 3.0
 	 */